<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Cordero
 */

if ( ! function_exists( 'cordero_posted_on' ) ) :
	/**
	 * Prints HTML with meta information for the current post-date/time.
	 */
	function cordero_posted_on() {
		$time_string = '<time class="entry-date published updated" datetime="%1$s"' . cordero_schema_prop( 'time-publish', 'false' ) . '>%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s"' . cordero_schema_prop( 'time-publish', 'false' ) . '>%2$s</time><time class="updated" datetime="%3$s"' . cordero_schema_prop( 'time-update', 'false' ) . '>%4$s</time>';
		}

		$time_string = sprintf( $time_string,
			esc_attr( get_the_date( 'c' ) ),
			esc_html( get_the_date() ),
			esc_attr( get_the_modified_date( 'c' ) ),
			esc_html( get_the_modified_date() )
		);

		echo '<span class="posted-on">' . $time_string . '</span>';

	}
endif;

if ( ! function_exists( 'cordero_posted_by' ) ) :
	/**
	 * Prints HTML with meta information for the current author.
	 */
	function cordero_posted_by() {

		echo '<span class="byline"><span class="author vcard"' . cordero_schema_item( 'author', 'false' ) . '><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '"' . cordero_schema_prop( 'url', 'false' ) . '><span class="author-name"' . cordero_schema_prop( 'name', 'false' ) . '>' . esc_html( get_the_author() ) . '</span></a></span></span><span class="meta-separator">|</span>';

	}
endif;

if ( ! function_exists( 'cordero_entry_cats' ) ) :
	/**
	 * Prints HTML with meta information for the categories only.
	 */
	function cordero_entry_cats() {
		// Hide category text for pages.
		if ( 'post' === get_post_type() ) {

			/* translators: used between list items, there is a space after the comma */
			$list_item_seperator = esc_html__( ', ', 'cordero' );

			$categories_list = get_the_category_list( $list_item_seperator );
			if ( $categories_list ) {
				echo '<span class="meta-separator">|</span><span class="cat-links">' . $categories_list . '</span>';
			}

		}

	}
endif;

if ( ! function_exists( 'cordero_entry_footer' ) ) :
	/**
	 * Prints HTML with meta information for the categories, tags and comments.
	 */
	function cordero_entry_footer() {
		// Hide category and tag text for pages.
		if ( 'post' === get_post_type() ) {

			/* translators: used between list items, there is a space after the comma */
			$list_item_seperator = esc_html__( ', ', 'cordero' );

			$tags_list = get_the_tag_list( '', $list_item_seperator );
			if ( $tags_list ) {
				echo '<span class="tags-links"><i class="cordero-icon-tag"></i> ' . $tags_list . '</span>';
			}

		}

		if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			echo '<span class="comments-link">';
			comments_popup_link(
				sprintf(
					wp_kses(
						/* translators: %s: post title */
						__( 'Leave a Comment<span class="screen-reader-text"> on %s</span>', 'cordero' ),
						array(
							'span' => array(
								'class' => array(),
							),
						)
					),
					get_the_title()
				)
			);
			echo '</span>';
		}

		edit_post_link(
			sprintf(
				wp_kses(
					/* translators: %s: Name of current post. Only visible to screen readers */
					__( 'Edit <span class="screen-reader-text">%s</span>', 'cordero' ),
					array(
						'span' => array(
							'class' => array(),
						),
					)
				),
				get_the_title()
			),
			'<span class="edit-link">',
			'</span>'
		);
	}
endif;

if ( ! function_exists( 'cordero_post_thumbnail' ) ) :
	/**
	 * Displays an optional post thumbnail.
	 *
	 * Wraps the post thumbnail in an anchor element on index views, or a div
	 * element when on single views.
	 */
	function cordero_post_thumbnail() {
		if ( post_password_required() || is_attachment() || ! has_post_thumbnail() ) {
			return;
		}

		if ( is_singular() ) :
			?>
			<div class="post-thumbnail">
				<?php the_post_thumbnail( 'post-thumbnail', cordero_schema_prop( 'wp-thumb', 'false' ) ); ?>
			</div><!-- .post-thumbnail -->

		<?php else : ?>

		<a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true">
			<?php
			the_post_thumbnail( 'post-thumbnail', array(
				'alt' => the_title_attribute( array(
					'echo' => false,
				) ),
			) );
			?>
		</a>

		<?php
		endif; // End is_singular().
	}
endif;

if ( ! function_exists( 'cordero_related_post_thumbnail' ) ) :
	function cordero_related_post_thumbnail($related_id) {
		if ( post_password_required($related_id) || is_attachment($related_id) || ! has_post_thumbnail($related_id) ) {
			return;
		}
		?>

		<a class="post-thumbnail" href="<?php the_permalink($related_id); ?>" aria-hidden="true">
			<?php
			echo get_the_post_thumbnail( $related_id, 'post-thumbnail', array(
				'alt' => the_title_attribute( array(
					'echo' => false,
					'post' => $related_id,
				) ),
			) );
			?>
		</a>

		<?php
	}
endif;
